@@ -1,15 +1,12 @@
 
-#' Parliamentary Research Briefings.
+#' Parliamentary Research Briefings
 #'
-#' Imports data on  Parliamentary Research Briefings. To see a list of possible topics call \code{\link{research_topics_list}} or \code{\link{research_subtopics_list}} for both topics and subtopics. To see a list of briefing types, call \code{\link{research_types_list}}. This function can return results with newlines in the text of the abstract or description of the research briefing, represented as '\\n'.
-#' @param topic The topic of the parliamentary briefing.
-#' @param subtopic The subtopic of the parliamentary briefing.
-#' @param type The type of research briefing.
-#' @param extra_args Additional parameters to pass to API. Defaults to NULL.
-#' @param tidy Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.
-#' @param tidy_style The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
+#' Imports data on  Parliamentary Research Briefings. To see a list of possible topics call \code{\link{research_topics_list}} or \code{\link{research_subtopics_list}} for both topics and subtopics. To see a list of briefing types, call \code{\link{research_types_list}}. This function can return results with newlines in the text of the abstract or description of the research briefing, represented as \code{'\\n'}.
+#' @param topic The topic of the parliamentary briefing. Defaults to \code{NULL}.
+#' @param subtopic The subtopic of the parliamentary briefing. Defaults to \code{NULL}.
+#' @param type The type of research briefing. Defaults to \code{NULL}.
+#' @inheritParams all_answered_questions
 #' @return A tibble with details on parliamentary research briefings on the given topic.
-#' @keywords Parliamentary Research Briefings
 #' @seealso \code{\link{research_subtopics_list}}
 #' @seealso \code{\link{research_types_list}}
 #' @seealso \code{\link{research_topics_list}}
@@ -29,39 +26,41 @@
 #' x <- research_briefings(subtopic = research_subtopics_list[[7]][10])
 #'
 #' # Requests for certain briefing types can also be made using lists
-#' # created with 'research_types_list'.
+#' # created with `research_types_list`.
 #'
 #' research_types_list <- research_types_list()
 #'
 #' x <- research_briefings(type = research_types_list[[3]])
-#'
-#'
 #' }
 
-research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
+research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case", verbose = FALSE) {
+
+
+  if(verbose==TRUE){message("Connecting to API")}
 
     if (is.null(topic) == TRUE & is.null(subtopic) == TRUE) {
 
         if (is.null(type) == FALSE) {
-            type <- utils::URLencode(type)
-            query <- paste0("&subType.prefLabel=", type)
+
+            query <- utils::URLencode(paste0("&subType.prefLabel=", type))
+
         } else {
+
             query <- NULL
+
         }
 
-        baseurl <- "http://lda.data.parliament.uk/researchbriefings.json?&_pageSize=500"
-
-        message("Connecting to API")
+        baseurl <- "http://lda.data.parliament.uk/researchbriefings.json?"
 
         research <- jsonlite::fromJSON(paste0(baseurl, query, extra_args), flatten = TRUE)
 
-        jpage <- floor(research$result$totalResults/research$result$itemsPerPage)
+        jpage <- floor(research$result$totalResults/500)
 
         pages <- list()
 
         for (i in 0:jpage) {
-            mydata <- jsonlite::fromJSON(paste0(baseurl, query, "&_pageSize=500&_page=", i, extra_args), flatten = TRUE)
-            message("Retrieving page ", i + 1, " of ", jpage + 1)
+            mydata <- jsonlite::fromJSON(paste0(baseurl, query, extra_args, "&_pageSize=500&_page=", i), flatten = TRUE)
+            if(verbose==TRUE){message("Retrieving page ", i + 1, " of ", jpage + 1)}
             pages[[i + 1]] <- mydata$result$items
         }
 
@@ -78,36 +77,42 @@ research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra
         }
 
         if (is.null(subtopic) == FALSE) {
-            subtopic <- utils::URLencode(subtopic)
-            subtopic_query <- paste0("/", subtopic)
+
+            subtopic_query <- utils::URLencode(paste0("/", subtopic))
+
         } else {
+
             subtopic_query <- NULL
+
         }
 
         if (is.null(topic) == FALSE) {
+
             topic_query <- utils::URLencode(topic)
+
         }
 
         if (is.null(type) == FALSE) {
-            type <- utils::URLencode(type)
-            query <- paste0("&subType.prefLabel=", type)
+
+            query <- utils::URLencode(paste0("&subType.prefLabel=", type))
+
         } else {
+
             query <- NULL
+
         }
 
         baseurl <- "http://lda.data.parliament.uk/researchbriefings/bridgeterm/"
 
-        research <- jsonlite::fromJSON(paste0(baseurl, topic_query, subtopic_query, ".json?&_pageSize=500", query, extra_args),
-            flatten = TRUE)
+        research <- jsonlite::fromJSON(paste0(baseurl, topic_query, subtopic_query, ".json?", query, extra_args), flatten = TRUE)
 
-        jpage <- floor(research$result$totalResults/research$result$itemsPerPage)
+        jpage <- floor(research$result$totalResults/500)
 
         pages <- list()
 
         for (i in 0:jpage) {
-            mydata <- jsonlite::fromJSON(paste0(baseurl, topic_query, subtopic_query, ".json?", query, "&_pageSize=500&_page=",
-                i, extra_args), flatten = TRUE)
-            message("Retrieving page ", i + 1, " of ", jpage + 1)
+            mydata <- jsonlite::fromJSON(paste0(baseurl, topic_query, subtopic_query, ".json?", query, "&_pageSize=500&_page=", i, extra_args), flatten = TRUE)
+            if(verbose==TRUE){message("Retrieving page ", i + 1, " of ", jpage + 1)}
             pages[[i + 1]] <- mydata$result$items
         }
 
@@ -115,11 +120,11 @@ research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra
 
     }
 
-    if (nrow(df) == 0) {
+    if (nrow(df) == 0 && verbose==TRUE) {
         message("The request did not return any data. Please check your search parameters.")
     } else {
 
-        if (tidy == TRUE) {
+        if (tidy == TRUE) {##move to external utils file?
 
             df$date._value <- gsub("T", " ", df$date._value)
 
@@ -154,10 +159,4 @@ research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra
 
 #' @rdname research_briefings
 #' @export
-hansard_research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
-
-  df <- research_briefings(topic = topic, subtopic = subtopic, type = type, extra_args = extra_args, tidy = tidy, tidy_style = tidy_style)
-
-  df
-
-}
+hansard_research_briefings <- research_briefings
