@@ -1,29 +1,32 @@
 
-
-#'
-#'
 #' Lists of research briefing topics, subtopics and types.
 #'
-#' These functions do not accept any arguments.
+#' Returns lists of research briefing topics, subtopics and types. These functions do not accept any arguments.
 #'
-#' A list of Parliamentary Research Briefings topics.
 #' @rdname research_briefings_lists
-#' @return A list with the different research topics available.
+#' @return A list with the different research topics/subtopics/types available.
 #' @export
 #' @seealso \code{\link{research_briefings}}
-#' @keywords  Parliamentary Research Briefings
-#' @examples  \dontrun{
 #'
-#' research_topics_list <- research_topics_list()
+#' @section Member details functions:
+#' \describe{
+#' \item{research_topics_list}{A list with the different research topics available}
+#' \item{research_subtopics_list}{A list of Parliamentary Research Briefings topics}
+#' \item{research_types_list}{A list of types of Parliamentary Research Briefings}
 #' }
+#' @examples  \dontrun{
+#' research_topics_list <- research_topics_list()
 #'
+#' research_subtopics_list <- research_subtopics_list()
+#'
+#' research_types_list <- research_types_list()
+#' }
+
 research_topics_list <- function() {
 
     x <- jsonlite::fromJSON("http://lda.data.parliament.uk/researchbriefingtopics.json?", flatten = TRUE)
 
-    y <- x$result$items$prefLabel._value
-
-    research_topics_list <- as.list(y)
+    research_topics_list <- as.list(x$result$items$prefLabel._value)
 
     research_topics_list
 
@@ -32,32 +35,17 @@ research_topics_list <- function() {
 
 #' @rdname research_briefings_lists
 #' @export
-hansard_research_topics_list <- function(){
+hansard_research_topics_list <- research_topics_list
 
-  df <- research_topics_list()
-
-  df
-}
 
 
-#' A list of Parliamentary Research Briefings subtopics, grouped by topic.
 #' @rdname research_briefings_lists
-#' @return A list with the different research subtopics available.
 #' @export
-#' @keywords Parliamentary Research Briefings
-#' @examples  \dontrun{
-#'
-#' research_subtopics_list <- research_subtopics_list()
-#'
-#' }
-
 research_subtopics_list <- function() {
 
     x <- jsonlite::fromJSON("http://lda.data.parliament.uk/researchbriefingtopics.json?", flatten = TRUE)
 
-    y <- x$result$items$prefLabel._value
-
-    research_topics_list <- as.list(y)
+    research_topics_list <- as.list(x$result$items$prefLabel._value)
 
     research_subtopics_list <- list()
 
@@ -79,25 +67,11 @@ research_subtopics_list <- function() {
 
 #' @rdname research_briefings_lists
 #' @export
-hansard_research_subtopics_list <- function(){
-
-  df <- research_subtopics_list()
-
-  df
-}
+hansard_research_subtopics_list <- research_subtopics_list
 
 
-#' A list of types of Parliamentary Research Briefings.
 #' @rdname research_briefings_lists
-#' @return A list with the different types of research briefings.
 #' @export
-#' @keywords  Parliamentary Research Briefings
-#' @examples  \dontrun{
-#'
-#' research_types_list <- research_types_list()
-#'
-#' }
-
 research_types_list <- function() {
 
     x <- jsonlite::fromJSON("http://lda.data.parliament.uk/researchbriefingtypes.json?")
@@ -110,9 +84,4 @@ research_types_list <- function() {
 
 #' @rdname research_briefings_lists
 #' @export
-hansard_research_types_list <- function(){
-
-  df <- research_types_list()
-
-  df
-}
+hansard_research_types_list <- research_types_list
