@@ -5,10 +5,10 @@ test_that("constituencies functions return expected format", {
 
     skip_on_cran()
 
-    ctx <- hansard_constituencies(current = TRUE)
-    expect_length(ctx, 9)
+    ctx <- hansard_constituencies(current = TRUE, verbose=TRUE)
+    expect_length(ctx, 7)
     expect_true(tibble::is_tibble(ctx))
     expect_equal(nrow(ctx), 650)
-    expect_true(names(ctx)[5]=="ended_date_value")
+    expect_true(names(ctx)[6]=="started_date_value")
 
 })
